@@ -27,7 +27,7 @@ dependencies using raw pip. The virtual environment is not created, but one can
 issue `python3 -m venv venv/ && . venv/bin/activate` to create one.
 """
 
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 __author__ = "Fridolin Pokorny <fridex.devel@gmail.com>"
 __title__ = "micropipenv"
 
@@ -737,7 +737,10 @@ def install_requirements(pip_bin=_PIP_BIN, *, pip_args=None):  # type: (str, Opt
     except PipRequirementsNotLocked:
         _LOGGER.warning("!" * 80)
         _LOGGER.warning("!!!")
-        _LOGGER.warning("!!!\t\tThe provided requirements.txt file is not fully locked")
+        _LOGGER.warning("!!!\t\tProvenance and integrity of installed packages cannot be checked!")
+        _LOGGER.warning("!!!")
+        _LOGGER.warning("!!!\t\tThe provided requirements.txt file is not fully locked as not all dependencies are")
+        _LOGGER.warning("!!!\t\tpinned to specific versions with digests of artifacts to be installed.")
         _LOGGER.warning("!!!")
         _LOGGER.warning("!" * 80)
 
@@ -885,6 +888,9 @@ def _get_package_entry_str(
         result = "--editable {}".format(info.get("path", "."))
     else:
         result = package_name
+    
+    if info.get('file'):
+        result = "{}#egg{}".format(info.get("file"), package_name)
 
     if info.get("extras"):
         result += "[{}]".format(",".join(info["extras"]))
